@@ -1,4 +1,4 @@
-'''Implementation of the morphology file converter'''
+"""Implementation of the morphology file converter."""
 from morphio import LogLevel, Morphology
 
 from morph_tool.apical_point import apical_point_position, apical_point_section_segment
@@ -7,3 +7,16 @@ from morph_tool.converter import convert
 from morph_tool.exceptions import MorphToolException
 from morph_tool.morphio_diff import diff
 from morph_tool.spatial import point_to_section_segment
+
+
+__all__ = [
+    "LogLevel",
+    "Morphology",
+    "apical_point_position",
+    "apical_point_section_segment",
+    "axon_point_section",
+    "convert",
+    "MorphToolException",
+    "diff",
+    "point_to_section_segment",
+]
