@@ -1,11 +1,11 @@
-'''Provides two classes to work with neurondb files
+"""Provides two classes to work with neurondb files.
+
 The main use is to provide a neuronDB loader and a method to retrieve
 information as a dataframe.
 
 Example:
-
-old_release = MorphDB.from_neurondb(Path("/realease/one/neuronDB.xml"), label='old-release')
-new_release = MorphDB.from_neurondb(Path("/realease/two/neuronDB.xml"), label='new-release')
+old_release = MorphDB.from_neurondb(Path("/release/one/neuronDB.xml"), label='old-release')
+new_release = MorphDB.from_neurondb(Path("/release/two/neuronDB.xml"), label='new-release')
 total = old_release + new_release
 
 # neurondb information
@@ -13,7 +13,8 @@ print(total.df)
 
 # combined information (neurondb + morph_stats)
 print(total.features({'neurite': {'section_lengths': ['max']}}))
-'''
+"""
+
 import collections
 import logging
 from pathlib import Path
@@ -47,15 +48,16 @@ COLUMNS = ['name', 'mtype', 'msubtype', 'mtype_no_subtype',
 
 
 class MorphInfo:
-    '''A class the contains information about a morphology.
+    """A class the contains information about a morphology.
+
     Its role is to abstract away the raw data.
-    '''
+    """
 
     MTYPE_SEPARATOR = ':'
 
     def __init__(self, name: str, mtype: str, layer: Optional[Union[str, int]] = None,
                  **kwargs):
-        '''MorphInfo ctor:
+        """A MorphInfo constructor.
 
         Upon initialization, all repair attributes are set to True.
 
@@ -77,7 +79,7 @@ class MorphInfo:
                 - axon_inputs
                 - path
                 - label
-        '''
+        """
         self.name = name
         self.mtype = mtype
         if self.MTYPE_SEPARATOR in mtype:
@@ -95,11 +97,12 @@ class MorphInfo:
 
     @classmethod
     def _from_xmldict(cls, item: Dict[str, Any]):
-        '''MorphInfo ctor.
+        """A MorphInfo constructor.
+
         Args:
             item: A dictionary that represents the content of the XML file.
                   The only mandatory keys are [name, mtype, layer]
-        '''
+        """
         morph = cls(
             item['name'],
             cls.MTYPE_SEPARATOR.join(filter(None, [item['mtype'], item.get('msubtype')])),
@@ -107,14 +110,15 @@ class MorphInfo:
         )
 
         def is_true(repair: Dict[str, Any], key: str) -> bool:
-            '''Parse a string representing a boolean repair flag and returns its boolean value
+            """Parse a string representing a boolean repair flag and returns its boolean value.
+
             Unless clearly stated as false, missing tags default to True
             - According to Eilif, an empty use_axon (corresponding to a null in the database)
               means that the axon is supposed to be used
             - dendrite_repair       defaults to True in BlueRepairSDK
             - basal_dendrite_repair defaults to True in BlueRepairSDK
             - unravel: well I guess we always want to do it
-            '''
+            """
             el = repair.get(key)
             if el not in {'true', 'false', 'True', 'False', None}:
                 raise ValueError(f'Invalid XML element {key} has invalid value: {el}\n'
@@ -140,19 +144,21 @@ class MorphInfo:
 
     @property
     def row(self) -> List:
-        '''Flattened data structude ready to be used by a dataframe.'''
+        """Flattened data structude ready to be used by a dataframe."""
         return [getattr(self, attr) for attr in COLUMNS]
 
     def __repr__(self):
+        """Overloaded method."""
         return (f'MorphInfo(name={self.name!r}, mtype={self.mtype!r}, layer={self.layer!r}, '
                 f'label={self.label!r})')
 
 
 class MorphDB:
-    '''A MorphInfo container.
+    """A MorphInfo container.
+
     It takes care of maintaining uniqueness of the MorphInfo element
     and methods to write neurondb to various format (xml, dat, csv)
-    '''
+    """
 
     def __init__(self, morph_info_seq: Optional[Iterable[MorphInfo]] = None):
         """Constructor of MorphDB.
@@ -166,10 +172,10 @@ class MorphDB:
 
     @classmethod
     def _from_neurondb_dat(cls, neurondb, morph_paths, label):
-        '''Private constructor from neuronDB.dat files
+        """Private constructor from neuronDB.dat files.
 
         The equivalent public method is MorphDB.from_neurondb
-        '''
+        """
         obj = cls()
         columns = ['name', 'layer', 'mtype']
         obj.df = pd.read_csv(neurondb, sep=r'\s+', names=columns, usecols=range(len(columns)))
@@ -221,7 +227,8 @@ class MorphDB:
                       neurondb: Union[Path, str],
                       label: str = 'default',
                       morphology_folder: Optional[Union[Path, str]] = None):
-        '''Builds a MorphologyDB from a neurondb.(xml|dat) file
+        """Builds a MorphologyDB from a neurondb.(xml|dat) file.
+
         Args:
             neurondb: path to a neurondb.(xml|dat) file
             label: a unique label to mark all morphologies coming from this neurondb
@@ -232,7 +239,7 @@ class MorphDB:
         https://bbpteam.epfl.ch/documentation/projects/morphology-repair-workflow/latest/input_files.html#specification
 
         ..note:: missing keys are filled with `True` values
-        '''
+        """
         neurondb = Path(neurondb)
         if morphology_folder:
             morphology_folder = Path(morphology_folder)
@@ -252,17 +259,20 @@ class MorphDB:
                     mtypes: Iterable[Tuple[str, str]],
                     label: str = 'default',
                     extension: Optional[str] = None):
-        '''Factory method to create a MorphDB object from a folder containing morphologies
+        """Factory method to create a MorphDB object from a folder containing morphologies.
 
         Args:
             morphology_folder: a folder containing morphologies
             mtypes: a sequence of 2-tuples (morphology name, mtype)
             label: (optional) a group label to be used to identify the morphlogies from this folder
-            ext: Specify the morphology format to consider, if the folder contains multiple formats
+            extension: Specify the morphology format to consider, if the folder contains multiple
+                formats
 
         Raises: ValueError if the folder contains multiple files with the same name but
         different extensions and the extension argument has not been provided
-        '''
+        Returns:
+            MorphDB: an instance of MorphDB.
+        """
         files = list(iter_morphology_files(Path(morphology_folder),
                                            extensions={extension} if extension else None))
         if not extension:
@@ -274,13 +284,13 @@ class MorphDB:
                     f'Folder {morphology_folder} have multiple morphologies with the same '
                     'name but different extensions. This is not supported.\n'
                     f'Duplicate morphogies: {duplicates}\n\n'
-                    'Please provide the extension to use with the arguement: extension')
+                    'Please provide the extension to use with the argument: extension')
         paths = {path.stem: path for path in files}
         return MorphDB(MorphInfo(name, mtype, label=label, path=paths[name])
                        for name, mtype in mtypes)
 
     def _to_xmldict(self):
-        '''Transform the data to a xmldict compatible dictionary'''
+        """Transform the data to a xmldict compatible dictionary."""
         def get_repair_attr(morph, attr):
             if attr == 'axon_inputs':
                 return 'axon_sources', {'axoninput': getattr(morph, attr)}
@@ -301,25 +311,25 @@ class MorphDB:
         }}
 
     def write(self, output_path: Union[Path, str]):
-        '''Write the neurondb file to XML or DAT format
+        """Write the neurondb file to XML or DAT format.
 
         Args:
             output_path: the output path
-        '''
+        """
         output_path = Path(output_path)
         ext = output_path.suffix.lower()
         if ext == '.dat':
             self.df[['name', 'layer', 'mtype']].to_csv(output_path, sep=' ', header=False,
                                                        index=False)
         elif ext == '.xml':
-            with output_path.open('w') as fd:
+            with output_path.open('w', encoding='utf-8') as fd:
                 fd.write(xmltodict.unparse(self._to_xmldict(), pretty=True))
         else:
             raise ValueError(f'Unsupported neurondb extensions ({ext}).'
                              ' Should be one of: (xml,csv,dat)')
 
     def features(self, config: Dict, n_workers=1):
-        '''Returns a dataframe containing morphometrics and neurondb information
+        """Returns a dataframe containing morphometrics and neurondb information.
 
         Args:
             config: a NeuroM morph_stas config.
@@ -331,7 +341,7 @@ class MorphDB:
 
         Raises:
             ValueError: if `self.df` has undefined (ie. None) paths
-        '''
+        """
         missing_morphs = self.df[self.df.path.isnull()].name.to_list()
         if missing_morphs:
             raise ValueError(
@@ -343,7 +353,7 @@ class MorphDB:
         return df.join(stats.drop(columns='name', level=1), how='inner')
 
     def check_files_exist(self):
-        '''Raises if `self.df.path` has None values or non existing paths'''
+        """Raises if `self.df.path` has None values or non existing paths."""
         missing_morphs = self.df[self.df.path.isnull()].name.values
         if missing_morphs:
             raise ValueError(
@@ -354,12 +364,14 @@ class MorphDB:
                 raise ValueError(f'Non existing path: {path}')
 
     def __add__(self, other):
+        """Overloaded method."""
         obj = MorphDB()
         obj += self
         obj += other
         return obj
 
     def __iadd__(self, other):
+        """Overloaded method."""
         if isinstance(other, MorphDB):
             self.df = pd.concat([self.df, other.df])
             MorphDB._sanitize_df_types(self.df)
@@ -370,7 +382,9 @@ class MorphDB:
 
     @staticmethod
     def _create_dataframe(morphologies: List[MorphInfo]):
-        '''Returns a pandas.DataFrame view of the data with the following columns:
+        """Creates a dataframe.
+
+        The dataframe has the following columns:
            'name': the morpho name (without extension)
            'mtype': the mtype with its subtype
            'msubtype': the msubtype (the part of the mtype after the ":")
@@ -392,17 +406,17 @@ class MorphDB:
            # deprecated
            'use_for_stats': Legacy flag that was used to determine if an axon was suitable to be
                             used as a axoninput
-        '''
+        """
         df = pd.DataFrame([morph.row for morph in morphologies], columns=COLUMNS)
         MorphDB._sanitize_df_types(df)
         return df
 
     @staticmethod
     def _sanitize_df_types(df):
-        '''Set up the proper types for each columns
+        """Set up the proper types for each columns.
 
         Args:
             df: the dataframe to be sanitized
-        '''
+        """
         df.astype({key: bool for key in BOOLEAN_REPAIR_ATTRS}, copy=False)
         df["axon_inputs"] = df["axon_inputs"].apply(tuple)
