@@ -1,4 +1,4 @@
-"""Utils related to the NRN simulator"""
+"""Utils related to the NRN simulator."""
 import logging
 import multiprocessing.pool
 from pathlib import Path
@@ -20,7 +20,7 @@ L = logging.getLogger(__name__)
 
 
 def get_NRN_cell(filename: Path):
-    """Returns a NRN cell"""
+    """Returns a NRN cell."""
     try:
         # pylint: disable=import-outside-toplevel
         from bluepyopt import ephys
@@ -45,7 +45,7 @@ def _zero_length_section(section, epsilon=1e-8):
 
 
 def _validate_section(nrn_neuron, nrm_neuron, nrm_idx, nrn_idx):
-    """raise if the mapping NeuroM_section_to_NRN_section is not correct"""
+    """Raise if the mapping NeuroM_section_to_NRN_section is not correct."""
     NRN_sections = list(nrn_neuron.icell.all)
 
     nrm_s = nrm_neuron.sections[nrm_idx]
@@ -61,10 +61,11 @@ def _validate_section(nrn_neuron, nrm_neuron, nrm_idx, nrn_idx):
     nrn_pts = [nrn_s.x3d(0), nrn_s.y3d(0), nrn_s.z3d(0)]
     nrm_pts = nrm_s.points[0, COLS.XYZ]
 
-    err_msg = ('ERROR Section mismatch: NRN ID ({}) != NeuroM ID ({})'
-               'NRN section:\n{}\n\nNeuroM section:\n{}'.format(
-                   nrn_idx, nrm_idx,
-                   nrn_pts, nrm_pts))
+    err_msg = (f'ERROR Section mismatch: NRN ID ({nrn_idx}) != NeuroM ID ({nrm_idx})'
+               'NRN section:\n'
+               f'{nrn_pts}\n\n'
+               'NeuroM section:\n'
+               f'{nrm_pts}')
     assert_almost_equal(nrn_pts,
                         nrm_pts,
                         decimal=2,
@@ -72,13 +73,13 @@ def _validate_section(nrn_neuron, nrm_neuron, nrm_idx, nrn_idx):
 
 
 def _validate_section_mapping(NeuroM_cell, NRN_cell, mapping):
-    """raise if the mapping NeuroM_section_to_NRN_section is not correct"""
+    """Raise if the mapping NeuroM_section_to_NRN_section is not correct."""
     for nrm_idx, nrn_idx in mapping.items():
         _validate_section(NRN_cell, NeuroM_cell, nrm_idx, nrn_idx)
 
 
 def NeuroM_section_to_NRN_section(filename: Path):
-    """Returns a mapping from NeuroM section IDs to NRN ones"""
+    """Returns a mapping from NeuroM section IDs to NRN ones."""
     NeuroM_cell = load_morphology(filename)
     NRN_cell = get_NRN_cell(filename)
 
@@ -87,7 +88,7 @@ def NeuroM_section_to_NRN_section(filename: Path):
     NRN_sections = list(NRN_cell.icell.all)
 
     def is_soma(NRN_section):
-        """Is the NRN section a soma section"""
+        """Is the NRN section a soma section."""
         return NRN_section.name().endswith('.soma[0]')
 
     # Skip soma if exists
@@ -127,8 +128,7 @@ def NeuroM_section_to_NRN_section(filename: Path):
 
 
 def _interpolate_compartments(points, boundaries_segment_ids, boundaries_positions):
-    """
-    Returns the path of each compartment based on its starting and ending position
+    """Returns the path of each compartment based on its starting and ending position.
 
     Args:
         points (numpy.array): a 3D array of the section points
@@ -158,13 +158,12 @@ def _interpolate_compartments(points, boundaries_segment_ids, boundaries_positio
 
 
 def _compartment_paths(points, n_compartments):
-    """
-    Returns the list of paths (list of 3D points) that form each compartment
+    """Returns the list of paths (list of 3D points) that form each compartment.
+
     Args:
         points (numpy.array): a 3D array of points
         n_compartments (int): the number of compartments
     """
-
     segments_directions = np.diff(points, axis=0)
     segment_lengths = np.linalg.norm(segments_directions, axis=1)
     cumulative_pathlength = np.append(0, np.cumsum(segment_lengths))
@@ -194,7 +193,7 @@ def _compartment_paths(points, n_compartments):
 
 
 def NeuroM_section_to_NRN_compartment_paths(morph_path: Path):
-    """Returns a dictionary NeuroM section id -> path of each compartment for the section
+    """Returns a dictionary NeuroM section id -> path of each compartment for the section.
 
     Path are formed by following the section points until the pathlength of the compartment is
     reached.
@@ -202,34 +201,33 @@ def NeuroM_section_to_NRN_compartment_paths(morph_path: Path):
     Args:
         morph_path: the morphology path
 
-
     1) Compute the cumulative pathlength along the section segments_directions
     2) Get the compartment pathlengths (compartment are of equal pathlength in a given section)
     3) Compartment by compartment, follow the points until the compartment pathlength is reached
 
 
-    Example for one section:
+    Example for one section::
 
-                   (1, 2) ------ (2, 2)
-                      |
-                      |
-                      |
-    (0, 0) ------- (1, 0)
+                       (1, 2) ------ (2, 2)
+                          |
+                          |
+                          |
+        (0, 0) ------- (1, 0)
 
 
-    If n_compartments == 3, three paths are returned:
-    [array([[0.        , 0.        , 0.        ],
-            [1.        , 0.        , 0.        ],
-            [1.        , 0.33333333, 0.        ]]),
+    If n_compartments == 3, three paths are returned::
 
-     array([[1.        , 0.33333333, 0.        ],
-            [1.        , 1.66666667, 0.        ]]),
+        [array([[0.        , 0.        , 0.        ],
+                [1.        , 0.        , 0.        ],
+                [1.        , 0.33333333, 0.        ]]),
 
-     array([[1.        , 1.66666667, 0.        ],
-            [1.        , 2.        , 0.        ],
-            [2.        , 2.        , 0.        ]])]
+         array([[1.        , 0.33333333, 0.        ],
+                [1.        , 1.66666667, 0.        ]]),
+
+         array([[1.        , 1.66666667, 0.        ],
+                [1.        , 2.        , 0.        ],
+                [2.        , 2.        , 0.        ]])]
     """
-
     NeuroM_cell = load_morphology(morph_path)
     NRN_neuron = get_NRN_cell(morph_path)
     NRN_sections = list(NRN_neuron.icell.all)
@@ -254,17 +252,17 @@ def point_to_section_end(sections: Sequence[neuron.nrn.Section],  # pylint: disa
                          point: List[float],
                          atol: float = 1e-08,
                          rtol: float = 1e-05) -> Union[None, int]:
-    '''Returns the index of the first found section whose end is at a distance less than
-    EPSILON from POINT. If no section satisfies this requirement, returns None
+    """Returns the index of the first section whose end is close to ``point``.
 
-    The iteration order is given by the section index.
+    The distance between the end and ``point`` must be less than EPSILON from POINT. If no section
+    satisfies this requirement, returns None. The iteration order is given by the section index.
 
     Args:
         sections: a sequence of sections
         point: the points's 3D coordinates
         atol: absolute tolerance
         rtol: relative tolerance
-    '''
+    """
     point = np.asarray(point)
 
     for index, section in enumerate(sections):
@@ -279,10 +277,10 @@ def point_to_section_end(sections: Sequence[neuron.nrn.Section],  # pylint: disa
 
 
 class NestedPool(multiprocessing.pool.Pool):  # pylint: disable=abstract-method
-    """Class that represents a MultiProcessing nested pool"""
+    """Class that represents a MultiProcessing nested pool."""
 
     class Process(multiprocessing.Process):
-        """Class that represents a non-daemon process"""
+        """Class that represents a non-daemon process."""
 
         def __init__(self, *args, **kwargs):
             """Ensures group=None to avoid exception from multiprocessing.
@@ -296,11 +294,12 @@ class NestedPool(multiprocessing.pool.Pool):  # pylint: disable=abstract-method
 
         @property
         def daemon(self):
+            """Stub method. Always returns False."""
             return False
 
         @daemon.setter
         def daemon(self, value):
-            pass
+            """Stub method. Does not do anything."""
 
 
 def isolate(func):
@@ -310,6 +309,8 @@ def isolate(func):
 
     Example:
 
+    .. code-block:: python
+
         def _to_be_isolated(morphology_path, point):
             cell = nrnhines.get_NRN_cell(morphology_path)
             return nrnhines.point_to_section_end(cell.icell.all, point)
