@@ -1,24 +1,23 @@
-'''Module for spatial related functions'''
+"""Module for spatial related functions."""
 import numpy as np
 
 from neurom import COLS
 
 
 def point_to_section_segment(neuron, point, rtol=1e-05, atol=1e-08):
-    '''Find section and segment that matches the point.
+    """Find section and segment that matches the point.
 
     Only the first point found with the *exact* same coordinates as the point argument is considered
 
     Args:
         neuron (morphio.Morphology): neuron object
         point (point): value of the point to find in the h5 file
-        rtol, atol (floats): precission of np.isclose
+        rtol, atol (floats): precision of np.isclose
 
     Returns:
         Tuple: (NeuroM/MorphIO section ID, point ID) of the point the matches the input coordinates.
         Since NeuroM v2, section ids of NeuroM and MorphIO are the same excluding soma.
-    '''
-
+    """
     for section in neuron.iter():
         points = section.points
         offset = np.where(
@@ -27,4 +26,4 @@ def point_to_section_segment(neuron, point, rtol=1e-05, atol=1e-08):
         if offset[0].size:
             return section.id, offset[0][0]
 
-    raise ValueError('Cannot find point in morphology that matches: {}'.format(point))
+    raise ValueError(f'Cannot find point in morphology that matches: {point}')
