@@ -5,15 +5,15 @@ import pandas as pd
 from bluepysnap.sonata_constants import Edge
 from plotly.offline import plot
 
-from nose.tools import assert_raises
+import pytest
 
-from morph_tool import dendrogram
+from morph_tool.plot import dendrogram
 
 DATA = Path(__file__).resolve().parent / 'data'
 
 
 def _create_test_neuron():
-    return nm.load_neuron(DATA / 'simple.swc')
+    return nm.load_morphology(DATA / 'simple.swc')
 
 
 def _create_test_synapses(target_node_ids):
@@ -57,6 +57,5 @@ def test_implicit_valid_neuron_node_id():
 
 def test_implicit_invalid_neuron_node_id():
     neuron_node_id = 1
-    with assert_raises(ValueError) as cm:
+    with pytest.raises(ValueError, match='neuron_node_id'):
         dendrogram.draw(_create_test_neuron(), _create_test_synapses([neuron_node_id, 2]))
-    assert 'neuron_node_id' in cm.exception.args[0].lower()
